import sys
from .listreqs_sh import listreqs


def main():
    listreqs()

if __name__ == '__main__':
    main()